Index: build/android/pylib/utils/test_environment.py |
diff --git a/build/android/pylib/utils/test_environment.py b/build/android/pylib/utils/test_environment.py |
index f55a4acc100997aeb1bc5b4e7ee69caca73056d8..3b31d4675b4c78619490398d5034cfb3b57ad0db 100644 |
--- a/build/android/pylib/utils/test_environment.py |
+++ b/build/android/pylib/utils/test_environment.py |
@@ -30,8 +30,12 @@ def _KillWebServers(): |
logging.warning('Failed waiting for %s to die. %s', p.pid, e) |
-def CleanupLeftoverProcesses(): |
- """Clean up the test environment, restarting fresh adb and HTTP daemons.""" |
+def CleanupLeftoverProcesses(devices): |
+ """Clean up the test environment, restarting fresh adb and HTTP daemons. |
+ |
+ Args: |
+ devices: The devices to clean. |
+ """ |
_KillWebServers() |
device_utils.RestartServer() |
@@ -43,5 +47,5 @@ def CleanupLeftoverProcesses(): |
logging.error(str(e)) |
d.WaitUntilFullyBooted() |
- device_utils.DeviceUtils.parallel().pMap(cleanup_device) |
+ device_utils.DeviceUtils.parallel(devices).pMap(cleanup_device) |